"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDeployConfig = exports.updateBaseConfig = void 0;
const btp_utils_1 = require("@sap-ux/btp-utils");
const ui5_config_1 = require("@sap-ux/ui5-config");
const constants_1 = require("./constants");
/**
 * Updates the base config with the required custom tasks.
 *
 * @param isLib - whether the project is a library
 * @param basePath - the base path
 * @param baseConfig - the base config
 * @param fs - the memfs editor instance
 */
function updateBaseConfig(isLib, basePath, baseConfig, fs) {
    if (isLib) {
        const customTask = {
            name: constants_1.UI5_TASK_FLATTEN_LIB,
            afterTask: 'generateResourcesJson'
        };
        baseConfig.addCustomTasks([customTask]);
        fs.write(basePath, baseConfig.toString());
        baseConfig.removeConfig('builder');
    }
}
exports.updateBaseConfig = updateBaseConfig;
/**
 * Returns the deployment config.
 *
 * @param config - the deploy config
 * @param baseConfig - the base config
 * @returns the deploy config
 */
function getDeployConfig(config, baseConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        const target = {};
        if (config.target.destination !== undefined) {
            target.destination = config.target.destination;
        }
        if (config.target.url !== undefined) {
            target.url = config.target.url;
        }
        if (config.target.client) {
            target.client = config.target.client;
        }
        if (config.target.scp) {
            target.scp = true;
        }
        if (!(0, btp_utils_1.isAppStudio)()) {
            const backendConfigs = baseConfig.getBackendConfigsFromFioriToolsProxydMiddleware();
            for (const backend of backendConfigs) {
                if (backend.authenticationType === 'reentranceTicket') {
                    target.authenticationType = 'reentranceTicket';
                }
            }
        }
        const baseUi5Doc = baseConfig.removeConfig('server');
        const ui5DeployConfig = yield ui5_config_1.UI5Config.newInstance(baseUi5Doc.toString());
        ui5DeployConfig.addComment({
            comment: ' yaml-language-server: $schema=https://sap.github.io/ui5-tooling/schema/ui5.yaml.json',
            location: 'beginning'
        });
        ui5DeployConfig.addAbapDeployTask(target, config.app, true, ['/test/'], config.index);
        return ui5DeployConfig;
    });
}
exports.getDeployConfig = getDeployConfig;
//# sourceMappingURL=config.js.map